@@ -213,9 +213,10 @@ class GeminiRow(object):
                  gt_quals=None, variant_samples=None,
                  HET_samples=None, HOM_ALT_samples=None,
                  HOM_REF_samples=None, UNKNOWN_samples=None,
-                 formatter=DefaultRowFormat(None)):
+                 info=None,formatter=DefaultRowFormat(None)):
         self.row = row
         self.gts = gts
+        self.info = info
         self.gt_types = gt_types
         self.gt_phases = gt_phases
         self.gt_depths = gt_depths
@@ -224,7 +225,7 @@ class GeminiRow(object):
         self.gt_quals = gt_quals
         self.gt_cols = ['gts', 'gt_types', 'gt_phases',
                         'gt_depths', 'gt_ref_depths', 'gt_alt_depths',
-                        'gt_quals', "variant_samples", "HET_samples", "HOM_ALT_samples"]
+                        'gt_quals', "variant_samples", "HET_samples", "HOM_ALT_samples", "HOM_REF_samples"]
         self.formatter = formatter
         self.variant_samples = variant_samples
         self.HET_samples = HET_samples
@@ -337,7 +338,8 @@ class GeminiQuery(object):
 
     def run(self, query, gt_filter=None, show_variant_samples=False,
             variant_samples_delim=',', predicates=None,
-            needs_genotypes=False, show_families=False):
+            needs_genotypes=False, needs_genes=False,
+            show_families=False):
         """
         Execute a query against a Gemini database. The user may
         specify:
@@ -350,6 +352,7 @@ class GeminiQuery(object):
         self.show_variant_samples = show_variant_samples
         self.variant_samples_delim = variant_samples_delim
         self.needs_genotypes = needs_genotypes
+        self.needs_genes = needs_genes
         self.show_families = show_families
         if predicates:
             self.predicates += predicates
@@ -370,8 +373,8 @@ class GeminiQuery(object):
                 self.query_type = "select-genotypes"
             else:
                 self.gt_filter = self._correct_genotype_filter()
-                self.query_type = "filter-genotypes"
-
+                self.query_type = "filter-genotypes" 
+        
         self._apply_query()
         self.query_executed = True
 
@@ -452,8 +455,11 @@ class GeminiQuery(object):
             hom_alt_names = []
             hom_ref_names = []
             unknown_names = []
-
-
+            info = None
+            
+            if 'info' in self.report_cols:
+                info = compression.unpack_ordereddict_blob(row['info'])
+            
             if self._query_needs_genotype_info():
                 gts = compression.unpack_genotype_blob(row['gts'])
                 gt_types = \
@@ -491,10 +497,12 @@ class GeminiQuery(object):
             for idx, col in enumerate(self.report_cols):
                 if col == "*":
                     continue
-                if not col.startswith("gt") and not col.startswith("GT"):
+                if not col.startswith("gt") and not col.startswith("GT") and not col == "info":
                     fields[col] = row[col]
+                elif col == "info":
+                    fields[col] = self._info_dict_to_string(info)
                 else:
-                    # reuse the original column anme user requested
+                    # reuse the original column name user requested
                     # e.g. replace gts[1085] with gts.NA20814
                     if '[' in col:
                         orig_col = self.gt_idx_to_name_map[col]
@@ -541,7 +549,7 @@ class GeminiQuery(object):
             gemini_row = GeminiRow(fields, gts, gt_types, gt_phases,
                                    gt_depths, gt_ref_depths, gt_alt_depths,
                                    gt_quals, variant_names, het_names, hom_alt_names,
-                                   hom_ref_names, unknown_names,
+                                   hom_ref_names, unknown_names, info,
                                    formatter=self.formatter)
 
             if not all([predicate(gemini_row) for predicate in self.predicates]):
@@ -576,6 +584,9 @@ class GeminiQuery(object):
         Execute a query. Intercept gt* columns and
         replace sample names with indices where necessary.
         """
+        if self.needs_genes:
+            self.query = self._add_gene_col_to_query()
+ 
         if self._query_needs_genotype_info():
             # break up the select statement into individual
             # pieces and replace genotype columns using sample
@@ -644,7 +655,7 @@ class GeminiQuery(object):
         (gt_types[11] == 1)
         """
         corrected_gt_filter = []
-        tokens = re.split(r'[\s+]+', self.gt_filter)
+        tokens = re.split(r'[\s+]+', str(self.gt_filter))
         for token in tokens:
             if token.find("gt") >= 0 or token.find("GT") >= 0:
                 corrected = self._correct_genotype_col(token)
@@ -698,6 +709,24 @@ class GeminiQuery(object):
         # extract the original select columns
         return self.query
 
+    def _add_gene_col_to_query(self):
+        """
+        Add the gene column to the list of SELECT'ed columns
+        in a query.
+        """
+        if "from" not in self.query.lower():
+            sys.exit("Malformed query: expected a FROM keyword.")
+
+        (select_tokens, rest_of_query) = get_select_cols_and_rest(self.query)
+
+        if not any("gene" in s for s in select_tokens):
+
+            select_clause = ",".join(select_tokens) + \
+                        ", gene "
+            
+            self.query = "select " + select_clause + rest_of_query
+
+        return self.query
 
     def _split_select(self):
         """
@@ -738,7 +767,16 @@ class GeminiQuery(object):
                 self.all_columns_orig.append(token)
                 self.gt_name_to_idx_map[token] = new_col
                 self.gt_idx_to_name_map[new_col] = token
-
+    
+    def _info_dict_to_string(self, info):
+        "Flatten the VCF info-field OrderedDict into a string, including all arrays for allelic-level info"
+        if info is not None:
+            return ';'.join(['%s=%s' % (key, value) if not isinstance(value, list) \
+                             else '%s=%s' % (key, ','.join([str(v) for v in value])) \
+                             for (key, value) in info.items()])
+        else:
+            return None
+    
     def _tokenize_query(self):
         tokens = list(flatten([x.split(",") for x in self.query.split(" ")]))
         return tokens
