@@ -4,8 +4,6 @@ import sqlite3
 import os
 import sys
 import collections
-import subprocess as subp
-import re
 
 from bx.bbi.bigwig_file import BigWigFile
 from gemini.config import read_gemini_config
@@ -16,37 +14,42 @@ annos = {}
 def get_anno_files():
     config = read_gemini_config()
     anno_dirname = config["annotation_dir"]
-    return {
+    # Default annotations -- always found
+    annos = {
      'pfam_domain': os.path.join(anno_dirname, 'hg19.pfam.ucscgenes.bed.gz'),
-    'cytoband': os.path.join(anno_dirname, 'hg19.cytoband.bed.gz'),
-    'dbsnp': os.path.join(anno_dirname, 'dbsnp.137.vcf.gz'),
-    'clinvar': os.path.join(anno_dirname, 'clinvar_20130118.vcf.gz'),
-    'gwas': os.path.join(anno_dirname, 'hg19.gwas.bed.gz'),
-    'rmsk': os.path.join(anno_dirname, 'hg19.rmsk.bed.gz'),
-    'segdup': os.path.join(anno_dirname, 'hg19.segdup.bed.gz'),
-    'conserved': os.path.join(anno_dirname, '29way_pi_lods_elements_12mers.chr_specific.fdr_0.1_with_scores.txt.hg19.merged.bed.gz'),
-    'cpg_island': os.path.join(anno_dirname, 'hg19.CpG.bed.gz'),
-    'dgv': os.path.join(anno_dirname, 'hg19.dgv.bed.gz'),
-    'esp': os.path.join(anno_dirname,
-                        'ESP6500SI.all.snps_indels.vcf.gz'),
-    '1000g': os.path.join(anno_dirname,
-                          'ALL.wgs.integrated_phase1_v3.20101123.snps_indels_sv.sites.2012Oct12.vcf.gz'),
-    'recomb': os.path.join(anno_dirname,
-                           'genetic_map_HapMapII_GRCh37.gz'),
-    'gms': os.path.join(anno_dirname,
-                        'GRCh37-gms-mappability.vcf.gz'),
-    'grc': os.path.join(anno_dirname, 'GRC_patch_regions.bed.gz'),
-    'cse': os.path.join(anno_dirname, "cse-hiseq-8_4-2013-02-20.bed.gz"),
-    'encode_tfbs': os.path.join(anno_dirname,
-                                'wgEncodeRegTfbsClusteredV2.cell_count.20130213.bed.gz'),
-    'encode_dnase1': os.path.join(anno_dirname,
-                                  'stam.125cells.dnaseI.hg19.bed.gz'),
-    'encode_consensus_segs': os.path.join(anno_dirname,
-                                          'encode.6celltypes.consensus.bedg.gz'),
-    'gerp_bp': os.path.join(anno_dirname, 'hg19.gerp.bw'),
-    'gerp_elements': os.path.join(anno_dirname, 'hg19.gerp.elements.bed.gz'),
-    'vista_enhancers': os.path.join(anno_dirname, 'hg19.vista.enhancers.20131108.bed.gz'),
+     'cytoband': os.path.join(anno_dirname, 'hg19.cytoband.bed.gz'),
+     'dbsnp': os.path.join(anno_dirname, 'dbsnp.138.vcf.gz'),
+     'clinvar': os.path.join(anno_dirname, 'clinvar_20140303.vcf.gz'),
+     'gwas': os.path.join(anno_dirname, 'hg19.gwas.bed.gz'),
+     'rmsk': os.path.join(anno_dirname, 'hg19.rmsk.bed.gz'),
+     'segdup': os.path.join(anno_dirname, 'hg19.segdup.bed.gz'),
+     'conserved': os.path.join(anno_dirname, '29way_pi_lods_elements_12mers.chr_specific.fdr_0.1_with_scores.txt.hg19.merged.bed.gz'),
+     'cpg_island': os.path.join(anno_dirname, 'hg19.CpG.bed.gz'),
+     'dgv': os.path.join(anno_dirname, 'hg19.dgv.bed.gz'),
+     'esp': os.path.join(anno_dirname,
+                         'ESP6500SI.all.snps_indels.vcf.gz'),
+     '1000g': os.path.join(anno_dirname,
+                           'ALL.wgs.integrated_phase1_v3.20101123.snps_indels_sv.sites.2012Oct12.vcf.gz'),
+     'recomb': os.path.join(anno_dirname,
+                            'genetic_map_HapMapII_GRCh37.gz'),
+     'gms': os.path.join(anno_dirname,
+                         'GRCh37-gms-mappability.vcf.gz'),
+     'grc': os.path.join(anno_dirname, 'GRC_patch_regions.bed.gz'),
+     'cse': os.path.join(anno_dirname, "cse-hiseq-8_4-2013-02-20.bed.gz"),
+     'encode_tfbs': os.path.join(anno_dirname,
+                                 'wgEncodeRegTfbsClusteredV2.cell_count.20130213.bed.gz'),
+     'encode_dnase1': os.path.join(anno_dirname,
+                                   'stam.125cells.dnaseI.hg19.bed.gz'),
+     'encode_consensus_segs': os.path.join(anno_dirname,
+                                           'encode.6celltypes.consensus.bedg.gz'),
+     'gerp_elements': os.path.join(anno_dirname, 'hg19.gerp.elements.bed.gz'),
+     'vista_enhancers': os.path.join(anno_dirname, 'hg19.vista.enhancers.20131108.bed.gz'),
+     'cosmic': os.path.join(anno_dirname, 'hg19.cosmic.v67.20131024.gz'),     
     }
+    # optional annotations
+    if os.path.exists(os.path.join(anno_dirname, 'hg19.gerp.bw')):
+        annos['gerp_bp'] = os.path.join(anno_dirname, 'hg19.gerp.bw')
+    return annos
 
 class ClinVarInfo(object):
     def __init__(self):
@@ -285,6 +288,36 @@ def get_cpg_island_info(var):
         return True
     return False
 
+# def get_dbNSFP_info(var, impacts):
+#     """
+#     Returns Polyphen, SIFT, etc. from dbNSFP annotation file.
+#     One prediction per transcript.
+    
+#     LIMITATION: only handles bi-allelic loci
+#     """
+
+#     # is this variant predicted to be nonsynonymous for any of the transcripts?
+#     # if not, we can skip dnNSFP.
+#     non_syn_impacts = [imp for imp in impacts \
+#                                if imp.consequence == 'non_syn_coding']
+
+#     if len(non_syn_impacts) > 0:
+#         for hit in annotations_in_region(var, "dbnsfp", parser_type="tuple", naming="grch37"):
+
+#             if var.POS == int(hit[1]) and \
+#                var.REF == hit[2] and \
+#                var.ALT[0] == hit[3]:
+                
+#                 transcripts = hit[7].split(';')
+#                 aapos = hit[8].split(';')
+#                 pp_scores = hit[11].split(';')
+
+#                 if len(transcripts) != len(pp_scores):
+#                     print var.POS, var.REF, var.ALT[0], [i.transcript for i in non_syn_impacts], \
+#                           [i.polyphen_pred for i in non_syn_impacts], [i.polyphen_score for i in non_syn_impacts], \
+#                           hit[7], hit[8], hit[11], hit[12]
+#     else:
+#         pass
 
 def get_cyto_info(var):
     """
@@ -303,6 +336,9 @@ def get_gerp_bp(var):
     """
     Returns a summary of the GERP scores for the variant.
     """
+    if "gerp_bp" not in annos:
+        raise IOError("Need to download BigWig file with GERP scores per base pair. "
+                      "Run `gemini update --dataonly --extra gerp_bp")
     gerp = bigwig_summary(var, "gerp_bp")
     return gerp
 
@@ -340,6 +376,29 @@ def get_pfamA_domains(var):
     return ",".join(pfam_domain) if len(pfam_domain) > 0 else None
 
 
+def get_cosmic_info(var):
+    """
+    Returns a list of COSMIC ids associated with given variant
+
+    E.g. from COSMIC VCF
+    #CHROM  POS     ID      REF     ALT     QUAL    FILTER  INFO
+    chrM    1747    COSN408408      G       A       .       .       .
+    chrM    2700    COSN408409      G       A       .       .       .
+    chr1    42880262    COSM464635  G   C   .   .   AA=p.D224H;CDS=c.670G>C;CNT=1;GENE=RIMKLA;STRAND=+
+    chr1    42880269    COSM909628  G   A   .   .   AA=p.G226D;CDS=c.677G>A;CNT=1;GENE=RIMKLA;STRAND=+
+    chr1    42880284    COSM1502979 G   T   .   .   AA=p.C231F;CDS=c.692G>T;CNT=1;GENE=RIMKLA;STRAND=+
+    chr1    42880318    COSM681351  T   A   .   .   AA=p.F242L;CDS=c.726T>A;CNT=1;GENE=RIMKLA;STRAND=+
+    chr1    42880337    COSM464636  G   A   .   .   AA=p.D249N;CDS=c.745G>A;CNT=1;GENE=RIMKLA;STRAND=+
+    chr1    42880384    COSM909629  T   C   .   .   AA=p.N264N;CDS=c.792T>C;CNT=1;GENE=RIMKLA;STRAND=+
+    chr1    42880415    COSM909630  G   C   .   .   AA=p.G275R;CDS=c.823G>C;CNT=1;GENE=RIMKLA;STRAND=+
+    """
+    # report the first overlapping ClinVar variant Most often, just one).
+    cosmic_ids = []
+    for hit in annotations_in_region(var, "cosmic", "vcf", "ucsc"):
+        cosmic_ids.append(hit.id)
+    return ",".join(cosmic_ids) if len(cosmic_ids) > 0 else None
+
+
 def get_clinvar_info(var):
     """
     Returns a suite of annotations from ClinVar
