@@ -22,8 +22,20 @@ def index_variation(cursor):
     cursor.execute('''create index var_exonic_idx on variants(is_exonic)''')
     cursor.execute('''create index var_coding_idx on variants(is_coding)''')
     cursor.execute('''create index var_lof_idx on variants(is_lof)''')
+    cursor.execute('''create index var_som_idx on variants(is_somatic)''')
     cursor.execute('''create index var_depth_idx on variants(depth)''')
     cursor.execute('''create index var_gene_idx on variants(gene)''')
+    cursor.execute('''create index var_trans_idx on variants(transcript)''')
+    cursor.execute('''create index var_impact_idx on variants(impact)''')
+    cursor.execute('''create index var_impact_severity_idx on variants(impact_severity)''')
+    cursor.execute('''create index var_esp_idx on variants(aaf_esp_all)''')
+    cursor.execute('''create index var_1kg_idx on variants(aaf_1kg_all)''')
+    cursor.execute('''create index var_qual_idx on variants(qual)''')
+    cursor.execute('''create index var_homref_idx on variants(num_hom_ref)''')
+    cursor.execute('''create index var_homalt_idx on variants(num_hom_alt)''')
+    cursor.execute('''create index var_het_idx on variants(num_het)''')
+    cursor.execute('''create index var_unk_idx on variants(num_unknown)''')
+    cursor.execute('''create index var_callrate_idx on variants(call_rate)''')
 
 
 def index_variation_impacts(cursor):
@@ -35,18 +47,41 @@ def index_variation_impacts(cursor):
         '''create index varimp_lof_idx on variant_impacts(is_lof)''')
     cursor.execute('''create index varimp_impact_idx on \
                       variant_impacts(impact)''')
+    cursor.execute('''create index varimp_trans_idx on \
+                      variant_impacts(transcript)''')
+    cursor.execute('''create index varimp_gene_idx on \
+                      variant_impacts(gene)''')
 
 
 def index_samples(cursor):
     cursor.execute('''create unique index sample_name_idx on samples(name)''')
 
 
+def index_gene_detailed(cursor):
+    cursor.execute('''create index gendet_chrom_gene_idx on \
+                       gene_detailed(chrom, gene)''')
+    cursor.execute('''create index gendet_rvis_idx on \
+                       gene_detailed(rvis_pct)''')
+    cursor.execute('''create index gendet_transcript_idx on \
+                       gene_detailed(transcript)''')
+    cursor.execute('''create index gendet_ccds_idx on \
+                       gene_detailed(ccds_id)''')
+
+def index_gene_summary(cursor):
+    cursor.execute('''create index gensum_chrom_gene_idx on \
+                       gene_summary(chrom, gene)''')
+    cursor.execute('''create index gensum_rvis_idx on \
+                      gene_summary(rvis_pct)''')
+
 def create_indices(cursor):
     """
     Index our master DB tables for speed
     """
     index_variation(cursor)
+    index_variation_impacts(cursor)
     index_samples(cursor)
+    index_gene_detailed(cursor)
+    index_gene_summary(cursor)
 
 
 def create_tables(cursor):
@@ -163,6 +198,8 @@ def create_tables(cursor):
                     encode_consensus_huvec text,                \
                     encode_consensus_k562 text,                 \
                     vista_enhancers text,                       \
+                    cosmic_ids text,                            \
+                    info blob,                           \
                     PRIMARY KEY(variant_id ASC))''')
 
     cursor.execute('''create table if not exists variant_impacts  (   \
@@ -204,6 +241,41 @@ def create_tables(cursor):
                      resource text)''')
 
     cursor.execute('''create table if not exists version (version text)''')
+    
+    cursor.execute('''create table if not exists gene_detailed (       \
+                   uid integer,                                        \
+                   chrom text,                                         \
+                   gene text,                                          \
+                   is_hgnc bool,                                       \
+                   ensembl_gene_id text,                               \
+                   transcript text,                                    \
+                   biotype text,                                       \
+                   transcript_status text,                             \
+                   ccds_id text,                                       \
+                   hgnc_id text,                                       \
+                   cds_length text,                                    \
+                   protein_length text,                                \
+                   transcript_start text,                              \
+                   transcript_end text,                                \
+                   strand text,                                        \
+                   synonym text,                                       \
+                   rvis_pct float,                                     \
+                   PRIMARY KEY(uid ASC))''')
+                   
+    cursor.execute('''create table if not exists gene_summary (     \
+                    uid integer,                                    \
+                    chrom text,                                     \
+                    gene text,                                      \
+                    is_hgnc bool,                                   \
+                    ensembl_gene_id text,                           \
+                    hgnc_id text,                                   \
+                    transcript_min_start text,                      \
+                    transcript_max_end text,                        \
+                    strand text,                                    \
+                    synonym text,                                   \
+                    rvis_pct float,                                 \
+                    in_cosmic_census bool,                          \
+                    PRIMARY KEY(uid ASC))''')
 
 def create_sample_table(cursor, args):
     NUM_BUILT_IN = 6
@@ -231,7 +303,7 @@ def _insert_variation_one_per_transaction(cursor, buffer):
                                                              ?,?,?,?,?,?,?,?,?,?, \
                                                              ?,?,?,?,?,?,?,?,?,?, \
                                                              ?,?,?,?,?,?,?,?,?,?, \
-                                                             ?,?,?,?,?,?,?,?,?)', variant)
+                                                             ?,?,?,?,?,?,?,?,?,?,?)', variant)
             cursor.execute("END TRANSACTION")
         # skip repeated keys until we get to the failed variant
         except sqlite3.IntegrityError, e:
@@ -258,7 +330,7 @@ def insert_variation(cursor, buffer):
                                                          ?,?,?,?,?,?,?,?,?,?, \
                                                          ?,?,?,?,?,?,?,?,?,?, \
                                                          ?,?,?,?,?,?,?,?,?,?, \
-                                                         ?,?,?,?,?,?,?,?,?)', buffer)
+                                                         ?,?,?,?,?,?,?,?,?,?,?)', buffer)
 
         cursor.execute("END TRANSACTION")
     except sqlite3.ProgrammingError:
@@ -289,7 +361,21 @@ def insert_sample(cursor, sample_list):
                    "({0})".format(placeholders), sample_list)
     cursor.execute("END")
 
+def insert_gene_detailed(cursor, table_contents):
+    cursor.execute("BEGIN TRANSACTION")
+    cursor.executemany('insert into gene_detailed values (?,?,?,?,?,?,?,?,?, \
+                                                          ?,?,?,?,?,?,?,?)',
+                        table_contents)
+    cursor.execute("END")
+    
 
+def insert_gene_summary(cursor, contents):
+    cursor.execute("BEGIN TRANSACTION")
+    cursor.executemany('insert into gene_summary values (?,?,?,?,?,?,?,?, \
+                                                         ?,?,?,?)', 
+                        contents)
+    cursor.execute("END")
+    
 def insert_resources(cursor, resources):
     """Populate table of annotation resources used in this database.
     """
@@ -319,6 +405,11 @@ def empty_tables(cursor):
     cursor.execute('''delete * from samples''')
 
 
+def update_gene_summary_w_cancer_census(cursor, genes):
+    update_qry = "UPDATE gene_summary SET in_cosmic_census = ? "
+    update_qry += " WHERE gene = ? and chrom = ?"
+    cursor.executemany(update_qry, genes)
+
 @contextlib.contextmanager
 def database_transaction(db):
     conn = sqlite3.connect(db)
