@@ -3,13 +3,16 @@
 # native Python imports
 import os.path
 import sys
+import sqlite3
 
 import annotations
-from gemini_constants import *
 import subprocess
 from cluster_helper.cluster import cluster_view
+import database as gemini_db
 from gemini_load_chunk import GeminiLoader
 import uuid
+import time
+import datetime
 
 
 def load(parser, args):
@@ -27,7 +30,6 @@ def load(parser, args):
     else:
         load_singlecore(args)
 
-
 def load_singlecore(args):
     # create a new gemini loader and populate
     # the gemini db and files from the VCF
@@ -35,7 +37,11 @@ def load_singlecore(args):
     gemini_loader.store_resources()
     gemini_loader.store_version()
     gemini_loader.populate_from_vcf()
-    gemini_loader.build_indices_and_disconnect()
+
+    if not args.skip_gene_tables and not args.test_mode:
+        gemini_loader.update_gene_table()
+    if not args.test_mode:
+        gemini_loader.build_indices_and_disconnect()
 
     if not args.no_genotypes and not args.no_load_genotypes:
         gemini_loader.store_sample_gt_counts()
@@ -75,10 +81,27 @@ def merge_chunks_ipython(chunks, db, view):
         merge_chunks_ipython(tmp_dbs, db, view)
 
 def merge_chunks_multicore(chunks, db):
-    if len(chunks) == 1:
+    if len(chunks) <= 1:
+        ts = time.time()
+        st = datetime.datetime.fromtimestamp(ts).strftime('%Y-%m-%d %H:%M:%S')
+        print st, "indexing final database."
+
         os.rename(chunks[0], db)
+        main_conn = sqlite3.connect(db)
+        main_conn.isolation_level = None
+        main_curr = main_conn.cursor()
+        main_curr.execute('PRAGMA synchronous = OFF')
+        main_curr.execute('PRAGMA journal_mode=MEMORY')
+        
+        gemini_db.create_indices(main_curr)
+        
+        main_conn.commit()
+        main_curr.close()
         return db
     else:
+        ts = time.time()
+        st = datetime.datetime.fromtimestamp(ts).strftime('%Y-%m-%d %H:%M:%S')
+        print st, "merging", len(chunks), "chunks."
         procs = []
         sub_merges = get_chunks_to_merge(chunks)
         tmp_dbs = get_temp_dbs(len(sub_merges), os.path.dirname(sub_merges[0][0]))
@@ -132,10 +155,21 @@ def load_chunks_multicore(grabix_file, args):
     if args.load_gerp_bp is True:
         load_gerp_bp = "--load-gerp-bp"
 
+    skip_gene_tables = ""
+    if args.skip_gene_tables is True:
+        skip_gene_tables = "--skip-gene-tables"
+
+    test_mode = ""
+    if args.test_mode is True:
+        test_mode = "--test-mode"
+
     passonly = ""
     if args.passonly is True:
         passonly = "--passonly"
 
+    skip_info_string = ""
+    if args.skip_info_string is True:
+        skip_info_string = "--skip-info-string"
 
     submit_command = "{cmd}"
     vcf, _ = os.path.splitext(grabix_file)
@@ -156,7 +190,7 @@ def load_chunks_multicore(grabix_file, args):
         chunk_dbs.append(chunk_vcf + ".db")
 
     wait_until_finished(procs)
-    print "Done loading {0} variants in {1} chunks.".format(stop, chunk_num)
+    print "Done loading {0} variants in {1} chunks.".format(stop, chunk_num+1)
     return chunk_dbs
 
 def load_chunks_ipython(grabix_file, args, view):
@@ -182,10 +216,22 @@ def load_chunks_ipython(grabix_file, args, view):
     if args.load_gerp_bp is True:
         load_gerp_bp = "--load-gerp-bp"
 
+    skip_gene_tables = ""
+    if args.skip_gene_tables is True:
+        skip_gene_tables = "--skip-gene-tables"
+
+    test_mode = ""
+    if args.test_mode is True:
+        test_mode = "--test-mode"
+
     passonly = ""
     if args.passonly is True:
         passonly = "--passonly"
 
+    skip_info_string = ""
+    if args.skip_info_string is True:
+        skip_info_string = "--skip-info-string"
+
 
     vcf, _ = os.path.splitext(grabix_file)
     chunk_steps = get_chunk_steps(grabix_file, args)
@@ -198,7 +244,10 @@ def load_chunks_ipython(grabix_file, args, view):
                  "no_genotypes": no_genotypes,
                  "no_load_genotypes": no_load_genotypes,
                  "load_gerp_bp": load_gerp_bp,
-                 "passonly": passonly}
+                 "skip_gene_tables": skip_gene_tables,
+                 "test_mode": test_mode,
+                 "passonly": passonly,
+                 "skip_info_string": skip_info_string}
     chunk_dbs = view.map(load_chunk, chunk_steps, [load_args] * total_chunks)
 
     print "Done loading variants in {0} chunks.".format(total_chunks)
@@ -224,7 +273,8 @@ def gemini_pipe_load_cmd():
     grabix_cmd = "grabix grab {grabix_file} {start} {stop}"
     gemini_load_cmd = ("gemini load_chunk -v - {anno_type} {ped_file}"
                        " {no_genotypes} {no_load_genotypes} {no_genotypes}"
-                       " {load_gerp_bp} {passonly}"
+                       " {load_gerp_bp} {skip_gene_tables}"
+                       " {passonly} {skip_info_string} {test_mode}"
                        " -o {start} {vcf}.chunk{chunk_num}.db")
     return " | ".join([grabix_cmd, gemini_load_cmd])
 
