@@ -5,6 +5,7 @@ import os.path
 import sys
 import sqlite3
 import numpy as np
+import datetime
 from itertools import repeat
 
 # third-party imports
@@ -13,6 +14,7 @@ import cyvcf as vcf
 # gemini modules
 import version
 from ped import get_ped_fields, default_ped_fields, load_ped_file
+import gene_table
 import infotag
 import database
 import annotations
@@ -21,6 +23,7 @@ import severe_impact
 import popgen
 from gemini_constants import *
 from compression import pack_blob
+from gemini.config import read_gemini_config
 
 
 class GeminiLoader(object):
@@ -48,6 +51,8 @@ class GeminiLoader(object):
 
         self.buffer_size = buffer_size
         self._get_anno_version()
+        self._get_gene_detailed()
+        self._get_gene_summary()
 
         if self.args.anno_type == "VEP":
             if not self._is_proper_vep_input():
@@ -180,14 +185,11 @@ class GeminiLoader(object):
         Test whether the VCF header meets expectations for
         proper execution of VEP for use with Gemini.
         """
-        #support versions >2.4<73
-        format = "Consequence|Codons|Amino_acids|Gene|HGNC|Feature|EXON|PolyPhen|SIFT".upper()
-        #support version 73
-        format73 = "Consequence|Codons|Amino_acids|Gene|SYMBOL|Feature|EXON|PolyPhen|SIFT".upper()
+        #support versions 73-75
+        format = "Consequence|Codons|Amino_acids|Gene|SYMBOL|Feature|EXON|PolyPhen|SIFT|Protein_position|BIOTYPE".upper()
 
         if 'CSQ' in self.vcf_reader.infos and \
-                (format in str(self.vcf_reader.infos['CSQ']).upper() or \
-                format73 in str(self.vcf_reader.infos['CSQ']).upper()):
+            format in str(self.vcf_reader.infos['CSQ']).upper():
             return True
         return False
 
@@ -257,6 +259,7 @@ class GeminiLoader(object):
         encode_cons_seg = annotations.get_encode_consensus_segs(var)
         gerp_el = annotations.get_gerp_elements(var)
         vista_enhancers = annotations.get_vista_enhancers(var)
+        cosmic_ids = annotations.get_cosmic_info(var)
 
         # grab the GERP score for this variant if asked.
         gerp_bp = None
@@ -330,6 +333,11 @@ class GeminiLoader(object):
             gt_ref_depths = None
             gt_alt_depths = None
             gt_quals = None
+        
+        if self.args.skip_info_string is False:
+            info = var.INFO
+        else:
+            info = None
 
         # were functional impacts predicted by SnpEFF or VEP?
         # if so, build up a row for each of the impacts / transcript
@@ -404,7 +412,10 @@ class GeminiLoader(object):
                    encode_cons_seg.hepg2,
                    encode_cons_seg.huvec,
                    encode_cons_seg.k562,
-                   vista_enhancers]
+                   vista_enhancers,
+                   cosmic_ids,
+                   pack_blob(info)]
+        
         return variant, variant_impacts
 
     def _prepare_samples(self):
@@ -436,6 +447,64 @@ class GeminiLoader(object):
                 sample_list = [i, None, sample]
                 sample_list += list(repeat(None, len(default_ped_fields) - 2))
             database.insert_sample(self.c, sample_list)
+            
+    def _get_gene_detailed(self):
+        """
+        define a gene detailed table
+        """
+        #unique identifier for each entry
+        i = 0
+        table_contents = detailed_list = []
+        
+        config = read_gemini_config()
+        path_dirname = config["annotation_dir"]
+        file_handle = os.path.join(path_dirname, 'detailed_gene_table')
+        
+        for line in open(file_handle, 'r'):
+            field = line.strip().split("\t")
+            if not field[0].startswith("Chromosome"):
+                i += 1
+                table = gene_table.gene_detailed(field)
+                detailed_list = [str(i),table.chrom,table.gene,table.is_hgnc,
+                                 table.ensembl_gene_id,table.ensembl_trans_id, 
+                                 table.biotype,table.trans_status,table.ccds_id, 
+                                 table.hgnc_id,table.cds_length,table.protein_length, 
+                                 table.transcript_start,table.transcript_end,
+                                 table.strand,table.synonym,table.rvis]
+                table_contents.append(detailed_list)
+        database.insert_gene_detailed(self.c, table_contents)
+        
+    def _get_gene_summary(self):
+        """
+        define a gene summary table
+        """
+        #unique identifier for each entry
+        i = 0
+        contents = summary_list = []
+        
+        config = read_gemini_config()
+        path_dirname = config["annotation_dir"]
+        file = os.path.join(path_dirname, 'summary_gene_table')
+        
+        for line in open(file, 'r'):
+            col = line.strip().split("\t")
+            if not col[0].startswith("Chromosome"):
+                i += 1
+                table = gene_table.gene_summary(col)
+                # defaul cosmic census to False
+                cosmic_census = 0
+                summary_list = [str(i),table.chrom,table.gene,table.is_hgnc,
+                                table.ensembl_gene_id,table.hgnc_id,
+                                table.transcript_min_start,
+                                table.transcript_max_end,table.strand,
+                                table.synonym,table.rvis,cosmic_census]
+                contents.append(summary_list)
+        database.insert_gene_summary(self.c, contents)
+
+    def update_gene_table(self):
+        """
+        """
+        gene_table.update_cosmic_census_genes(self.c)
 
     def _init_sample_gt_counts(self):
         """
@@ -493,6 +562,7 @@ def load(parser, args):
     gemini_loader.store_version()
 
     gemini_loader.populate_from_vcf()
+    gemini_loader.update_gene_table()
     # gemini_loader.build_indices_and_disconnect()
 
     if not args.no_genotypes and not args.no_load_genotypes:
