@@ -10,7 +10,7 @@ import \
     gemini_region, gemini_stats, gemini_dump, \
     gemini_annotate, gemini_windower, \
     gemini_browser, gemini_dbinfo, gemini_merge_chunks, gemini_update, \
-    gemini_amend
+    gemini_amend, gemini_set_somatic, gemini_actionable_mutations
 
 import gemini.version
 
@@ -70,7 +70,7 @@ def main():
     #########################################
     # create the top-level parser
     #########################################
-    parser = argparse.ArgumentParser(prog='gemini')
+    parser = argparse.ArgumentParser(prog='gemini', formatter_class=argparse.ArgumentDefaultsHelpFormatter)
     parser.add_argument("-v", "--version", help="Installed gemini version",
                         action="version",
                         version="%(prog)s " + str(gemini.version.__version__))
@@ -103,6 +103,16 @@ def main():
                              action='store_true',
                              help='Load GERP scores at base pair resolution. Slow. Off by default.',
                              default=False)
+    parser_load.add_argument('--skip-gene-tables',
+                             dest='skip_gene_tables',
+                             action='store_true',
+                             help='Do not load gene tables. Loaded by default.',
+                             default=False)
+    parser_load.add_argument('--skip-info-string',
+                             dest='skip_info_string',
+                             action='store_true',
+                             help='Do not load INFO string from VCF file to reduce DB size. Loaded by default',
+                             default=False)
     parser_load.add_argument('--no-load-genotypes',
                              dest='no_load_genotypes',
                              action='store_true',
@@ -128,6 +138,11 @@ def main():
                              default=False,
                              action='store_true',
                              help="Keep only variants that pass all filters.")
+    parser_load.add_argument('--test-mode',
+                         dest='test_mode',
+                         action='store_true',
+                         help='Load in test mode (faster)',
+                         default=False)
 
     parser_load.set_defaults(func=gemini_load.load)
     #########################################
@@ -186,11 +201,26 @@ def main():
                                   action='store_true',
                                   help='Load GERP scores at base pair resolution. Slow. Off by default.',
                                   default=False)
+    parser_loadchunk.add_argument('--skip-gene-tables',
+                             dest='skip_gene_tables',
+                             action='store_true',
+                             help='Do not load gene tables. Loaded by default.',
+                             default=False)
+    parser_loadchunk.add_argument('--skip-info-string',
+                                  dest='skip_info_string',
+                                  action='store_true',
+                                  help='Do not load INFO string from VCF file to reduce DB size. Loaded by default',
+                                  default=False)
     parser_loadchunk.add_argument('--passonly',
                                   dest='passonly',
                                   default=False,
                                   action='store_true',
                                   help="Keep only variants that pass all filters.")
+    parser_loadchunk.add_argument('--test-mode',
+                         dest='test_mode',
+                         action='store_true',
+                         help='Load in test mode (faster)',
+                         default=False)
     parser_loadchunk.set_defaults(func=gemini_load_chunk.load)
 
     #########################################
@@ -285,6 +315,11 @@ def main():
                               help=('Output columns of counts of carriers and '
                                     'non-carriers stratified by the given '
                                     'sample phenotype column'))
+    parser_query.add_argument('--dgidb',
+                              dest='dgidb',
+                              action='store_true',
+                              help='Request drug-gene interaction info from DGIdb.',
+                              default=False)
 
     parser_query.set_defaults(func=gemini_query.query)
 
@@ -358,6 +393,12 @@ def main():
             dest='filter',
             metavar='STRING',
             help='Restrictions to apply to variants (SQL syntax)')
+    parser_region.add_argument('--show-samples',
+                               dest='show_variant_samples',
+                               action='store_true',
+                               default=False,
+                                help=('Add a column of all sample names with a variant to each '
+                                      'variant.'))
     parser_region.add_argument('--format',
                               dest='format',
                               default='default',
@@ -761,6 +802,89 @@ def main():
             help='The name of the database to be queried.')
     parser_browser.set_defaults(func=gemini_browser.browser_main)
 
+
+
+    #########################################
+    # $ gemini set_somatic
+    #########################################
+    parser_set_somatic = subparsers.add_parser("set_somatic",
+                          help="Tag somatic mutations (is_somatic) by comparint tumor/normal pairs.")
+    parser_set_somatic.add_argument('db', metavar='db',
+            help='The name of the database to be updated.')
+    parser_set_somatic.set_defaults(func=gemini_set_somatic.set_somatic)
+
+    parser_set_somatic.add_argument('--min-depth',
+            dest='min_depth',
+            type=float,
+            default=30,
+            help='The min combined depth for tumor + normal (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--min-qual',
+            dest='min_qual',
+            type=float,
+            default=30,
+            help='The min variant quality (VCF QUAL) (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--max-norm-alt-freq',
+            dest='max_norm_alt_freq',
+            type=float,
+            default=0.03,
+            help='The max freq. of the alt. allele in the normal sample (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--max-norm-alt-count',
+            dest='max_norm_alt_count',
+            type=int,
+            default=2,
+            help='The max count. of the alt. allele in the normal sample (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--min-norm-depth',
+            dest='min_norm_depth',
+            type=int,
+            default=10,
+            help='The minimum depth allowed in the normal sample to believe somatic (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--min-tumor-alt-freq',
+            dest='min_tumor_alt_freq',
+            type=float,
+            default=0.05,
+            help='The min freq. of the alt. allele in the tumor sample (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--min-tumor-alt-count',
+            dest='min_tumor_alt_count',
+            type=int,
+            default=2,
+            help='The min count. of the alt. allele in the tumor sample (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--min-tumor-depth',
+            dest='min_tumor_depth',
+            type=int,
+            default=10,
+            help='The minimum depth allowed in the tumor sample to believe somatic (def: %(default)s).')
+
+    parser_set_somatic.add_argument('--chrom',
+            dest='chrom',
+            metavar='STRING',
+            help='A specific chromosome on which to tag somatic mutations. (def: %(default)s).',
+            default=None,
+            )
+
+    parser_set_somatic.add_argument('--dry-run',
+            dest='dry_run',
+            action='store_true',
+            help='Don\'t set the is_somatic flag, just report what _would_ be set. For testing parameters.',
+            default=False)
+
+
+    #########################################
+    # $ gemini actionable_mutations
+    #########################################
+    parser_actionable_mut = subparsers.add_parser("actionable_mutations",
+                          help="Retriev genes with actionable somatic mutations via COSMIC and DGIdb.")
+    parser_actionable_mut.add_argument('db', metavar='db',
+            help='The name of the database to be queried.')
+    parser_actionable_mut.set_defaults(func=gemini_actionable_mutations.get_actionable_mutations)
+
+
     #########################################
     # $ gemini update
     #########################################
@@ -769,8 +893,11 @@ def main():
                                action="store_true", default=False)
     parser_update.add_argument("--dataonly", help="Only update data, not the underlying libraries.",
                                action="store_true", default=False)
+    parser_update.add_argument("--extra", help="Add additional non-standard genome annotations to include",
+                               action="append", default=[], choices=["gerp_bp"])
     parser_update.set_defaults(func=gemini_update.release)
 
+
     #######################################################
     # parse the args and call the selected function
     #######################################################
