@@ -28,7 +28,7 @@ remotes = {"requirements":
            "gemini":
            "https://github.com/arq5x/gemini.git",
            "anaconda":
-           "http://repo.continuum.io/miniconda/Miniconda-2.2.2-%s-x86_64.sh"}
+           "http://repo.continuum.io/miniconda/Miniconda-latest-%s-x86_64.sh"}
 
 def main(args):
     check_dependencies()
@@ -65,19 +65,32 @@ def install_gemini(anaconda, remotes, datadir, tooldir, use_sudo):
     """Install gemini plus python dependencies inside isolated Anaconda environment.
     """
     # Work around issue with distribute where asks for 'distribute==0.0'
-    try:
-        subprocess.check_call([anaconda["easy_install"], "--upgrade", "distribute"])
-    except subprocess.CalledProcessError:
-        try:
-            subprocess.check_call([anaconda["pip"], "install", "--upgrade", "distribute"])
-        except subprocess.CalledProcessError:
-            pass
+    # try:
+    #     subprocess.check_call([anaconda["easy_install"], "--upgrade", "distribute"])
+    # except subprocess.CalledProcessError:
+    #     try:
+    #         subprocess.check_call([anaconda["pip"], "install", "--upgrade", "distribute"])
+    #     except subprocess.CalledProcessError:
+    #         pass
     # Ensure latest version of fabric for running CloudBioLinux
     subprocess.check_call([anaconda["pip"], "install", "fabric>=1.7.0"])
     # Install problem dependency separately: bx-python
     subprocess.check_call([anaconda["pip"], "install", "--upgrade",
                            "https://bitbucket.org/james_taylor/bx-python/get/tip.tar.bz2"])
-    subprocess.check_call([anaconda["pip"], "install", "-r", remotes["requirements"]])
+    # allow downloads excluded in recent pip (1.5 or greater) versions
+    try:
+        p = subprocess.Popen([anaconda["pip"], "--version"], stdout=subprocess.PIPE)
+        pip_version = p.communicate()[0].split()[1]
+    except:
+        pip_version = ""
+    pip_compat = []
+    if pip_version >= "1.5":
+        for req in ["python-graph-core", "python-graph-dot"]:
+            pip_compat += ["--allow-external", req, "--allow-unverified", req]
+    subprocess.check_call([anaconda["pip"], "install"] + pip_compat + ["-r", remotes["requirements"]])
+    python_bin = os.path.join(anaconda["dir"], "bin", "python")
+    _cleanup_problem_files(anaconda["dir"])
+    _add_missing_inits(python_bin)
     for final_name, ve_name in [("gemini", "gemini"), ("gemini_python", "python"),
                                 ("gemini_pip", "pip")]:
         final_script = os.path.join(tooldir, "bin", final_name)
@@ -89,8 +102,6 @@ def install_gemini(anaconda, remotes, datadir, tooldir, use_sudo):
             subprocess.check_call(sudo_cmd + ["mkdir", "-p", os.path.dirname(final_script)])
         cmd = ["ln", "-s", ve_script, final_script]
         subprocess.check_call(sudo_cmd + cmd)
-    _cleanup_problem_files(anaconda["dir"])
-    python_bin = os.path.join(anaconda["dir"], "bin", "python")
     library_loc = subprocess.check_output("%s -c 'import gemini; print gemini.__file__'" % python_bin,
                                           shell=True)
     return {"fab": os.path.join(anaconda["dir"], "bin", "fab"),
@@ -101,6 +112,7 @@ def install_conda_pkgs(anaconda):
     pkgs = ["cython", "ipython", "jinja2", "nose", "numpy",
             "pip", "pycrypto", "pyparsing", "pysam", "pyyaml",
             "pyzmq", "pandas", "scipy"]
+    subprocess.check_call([anaconda["conda"], "install", "--yes", "numpy"])
     subprocess.check_call([anaconda["conda"], "install", "--yes"] + pkgs)
 
 def install_anaconda_python(args, remotes):
@@ -127,6 +139,19 @@ def install_anaconda_python(args, remotes):
             "easy_install": os.path.join(bindir, "easy_install"),
             "dir": anaconda_dir}
 
+def _add_missing_inits(python_bin):
+    """pip/setuptools strips __init__.py files with namespace declarations.
+    I have no idea why, but this adds them back.
+    """
+    library_loc = subprocess.check_output("%s -c 'import pygraph.classes.graph; "
+                                          "print pygraph.classes.graph.__file__'" % python_bin,
+                                          shell=True)
+    pygraph_init = os.path.normpath(os.path.join(os.path.dirname(library_loc.strip()), os.pardir,
+                                                 "__init__.py"))
+    if not os.path.exists(pygraph_init):
+        with open(pygraph_init, "w") as out_handle:
+            out_handle.write("__import__('pkg_resources').declare_namespace(__name__)\n")
+
 def _cleanup_problem_files(venv_dir):
     """Remove problem bottle items in PATH which conflict with site-packages
     """
