@@ -1,13 +1,3 @@
-check()
-{
-	if diff $1 $2; then
-    	echo ok
-	else
-    	echo fail
-	fi
-}
-export -f check
-
 ####################################################################
 # 1. Test the samples table
 ####################################################################
@@ -181,14 +171,14 @@ rm obs exp
 # 10. Test a query of the variants table with a select *
 ####################################################################
 echo "    query.t10...\c"
-echo "chr1	30547	30548	None	1	1	T	G	50.09	None	snp	tv	0.116666666667	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	None	0	1	0	None	None	4	0	3	53	0.428571428571	0.00815097309095	None	0.527472527473	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	7	None	29.0	0	0	14	0.0	0.0	16.7	6	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown
-chr1	30859	30860	None	2	1	G	C	54.3	None	snp	tv	0.433333333333	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	24	1	1	34	0.0576923076923	0.000983220876781	0.646258503401	0.110859728507	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	61	None	36.25	0	0	52	0.0	0.6396	13.57	3	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown
-chr1	30866	30869	None	3	1	CCT	C	49.48	None	indel	del	0.466666666667	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	23	4	1	32	0.107142857143	0.180078296859	0.253333333333	0.194805194805	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	65	None	36.09	0	0	56	None	12.2055	3.81	6	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown
-chr1	30894	30895	None	4	1	T	C	51.79	None	snp	ts	0.483333333333	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	26	2	1	31	0.0689655172414	0.0126621812074	0.462962962963	0.130671506352	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	63	None	36.09	0	0	58	0.0	0.2091	3.98	4	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown
-chr1	30922	30923	None	5	1	G	T	601.49	None	snp	tv	0.25	1	rs140337953	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	0	0	15	45	1.0	1	None	0	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	17	None	35.61	0	0	30	0.0	0.0	35.38	30	None	None	None	None	0	None	None	None	0	1	0.8	0.89	0.48	0.73	0.73	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown" > exp
+echo "chr1	30547	30548	None	1	1	T	G	50.09	None	snp	tv	0.116666666667
+chr1	30859	30860	None	2	1	G	C	54.3	None	snp	tv	0.433333333333
+chr1	30866	30869	None	3	1	CCT	C	49.48	None	indel	del	0.466666666667
+chr1	30894	30895	None	4	1	T	C	51.79	None	snp	ts	0.483333333333
+chr1	30922	30923	None	5	1	G	T	601.49	None	snp	tv	0.25" > exp
 gemini query -q "select * \
                  from variants \
-                 limit 5" test.query.db \
+                 limit 5" test.query.db | cut -f1-13 \
        > obs
 check obs exp
 rm obs exp
@@ -198,15 +188,14 @@ rm obs exp
 # 11. Test a query of the variants table with a select * and a genotype column
 ###############################################################################
 echo "    query.t11...\c"
-echo "chr1	30547	30548	None	1	1	T	G	50.09	None	snp	tv	0.116666666667	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	None	0	1	0	None	None	4	0	3	53	0.428571428571	0.00815097309095	None	0.527472527473	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	7	None	29.0	0	0	14	0.0	0.0	16.7	6	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	T/T
-chr1	30859	30860	None	2	1	G	C	54.3	None	snp	tv	0.433333333333	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	24	1	1	34	0.0576923076923	0.000983220876781	0.646258503401	0.110859728507	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	61	None	36.25	0	0	52	0.0	0.6396	13.57	3	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	G/G
-chr1	30866	30869	None	3	1	CCT	C	49.48	None	indel	del	0.466666666667	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	23	4	1	32	0.107142857143	0.180078296859	0.253333333333	0.194805194805	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	65	None	36.09	0	0	56	None	12.2055	3.81	6	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	CCT/CCT
-chr1	30894	30895	None	4	1	T	C	51.79	None	snp	ts	0.483333333333	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	26	2	1	31	0.0689655172414	0.0126621812074	0.462962962963	0.130671506352	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	63	None	36.09	0	0	58	0.0	0.2091	3.98	4	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	T/T
-chr1	30922	30923	None	5	1	G	T	601.49	None	snp	tv	0.25	1	rs140337953	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.33	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	0	0	15	45	1.0	1	None	0	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	17	None	35.61	0	0	30	0.0	0.0	35.38	30	None	None	None	None	0	None	None	None	0	1	0.8	0.89	0.48	0.73	0.73	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	./." > exp
+echo "chr1	30547	30548	T	G	T/T
+chr1	30859	30860	G	C	G/G
+chr1	30866	30869	CCT	C	CCT/CCT
+chr1	30894	30895	T	C	T/T
+chr1	30922	30923	G	T	./." > exp
 gemini query -q "select *, gts.1094PC0018 \
                   from variants \
-                  limit 5" test.query.db \
-        > obs
+                  limit 5" test.query.db | awk '{OFS="\t"}{print $1,$2,$3,$7,$8,$NF}' > obs
 check obs exp
 rm obs exp
 
@@ -215,14 +204,14 @@ rm obs exp
 # 12. Test a query of the variants table with a select * and the full genotype column
 ###############################################################################
 echo "    query.t12...\c"
-echo "chr1	30547	30548	None	1	1	T	G	50.09	None	snp	tv	0.116666666667	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.3	None	0	1	0	None	None	4	0	3	53	0.428571428571	0.00815097309095	None	0.527472527473	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	8	protein_coding	downstream	LOW	None	None	None	None	None	None	None	7	None	29.0	0	0	14	0.0	0.0	16.7	6	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	None	./.,./.,./.,./.,./.,./.,T/T,./.,./.,./.,./.,./.,./.,T/T,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,G/G,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,T/T,./.,G/G,./.,G/G,./.,./.,./.,./.,./.,T/T,./.,./.,./.,./.,./.,./.,./.
-chr1	30859	30860	None	2	1	G	C	54.3	None	snp	tv	0.433333333333	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.3	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	24	1	1	34	0.0576923076923	0.000983220876781	0.646258503401	0.110859728507	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	61	None	36.25	0	0	52	0.0	0.6396	13.57	3	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	None	G/G,G/G,G/G,G/G,./.,./.,G/G,./.,G/G,G/G,G/G,./.,./.,G/G,G/G,./.,./.,./.,./.,./.,G/G,./.,./.,G/G,./.,G/G,G/G,G/G,G/G,C/C,G/G,./.,G/G,./.,./.,./.,./.,./.,./.,./.,./.,./.,G/C,./.,G/G,./.,G/G,./.,./.,G/G,G/G,G/G,G/G,./.,./.,./.,./.,./.,./.,./.
-chr1	30866	30869	None	3	1	CCT	C	49.48	None	indel	del	0.466666666667	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.3	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	23	4	1	32	0.107142857143	0.180078296859	0.253333333333	0.194805194805	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	65	None	36.09	0	0	56	None	12.2055	3.81	6	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	None	CCT/CCT,CCT/CCT,CCT/C,CCT/CCT,./.,./.,CCT/CCT,./.,CCT/CCT,CCT/C,CCT/CCT,./.,./.,CCT/CCT,CCT/CCT,./.,./.,./.,./.,./.,CCT/CCT,./.,./.,CCT/C,./.,CCT/CCT,C/C,CCT/CCT,CCT/CCT,CCT/CCT,CCT/CCT,./.,CCT/CCT,./.,./.,./.,./.,CCT/CCT,./.,./.,./.,./.,CCT/C,./.,CCT/CCT,./.,CCT/CCT,CCT/CCT,./.,CCT/CCT,CCT/CCT,CCT/CCT,CCT/CCT,./.,./.,./.,./.,./.,./.,./.
-chr1	30894	30895	None	4	1	T	C	51.79	None	snp	ts	0.483333333333	0	None	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.3	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	26	2	1	31	0.0689655172414	0.0126621812074	0.462962962963	0.130671506352	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	63	None	36.09	0	0	58	0.0	0.2091	3.98	4	None	None	None	None	0	None	None	None	0	0	None	None	None	None	None	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	None	T/C,T/C,T/T,T/T,./.,./.,T/T,./.,T/T,T/T,T/T,./.,T/T,T/T,T/T,./.,./.,./.,T/T,./.,T/T,./.,./.,T/T,./.,./.,T/T,T/T,T/T,C/C,T/T,./.,T/T,./.,./.,./.,./.,T/T,./.,./.,./.,./.,T/T,./.,T/T,./.,T/T,T/T,./.,./.,T/T,T/T,T/T,T/T,./.,./.,./.,./.,./.,./.
-chr1	30922	30923	None	5	1	G	T	601.49	None	snp	tv	0.25	1	rs140337953	None	None	None	None	None	None	None	None	None	None	None	None	chr1p36.3	Simple_repeat_Simple_repeat_(TC)n;trf;LTR_ERVL-MaLR_MLT1A	0	1	0	None	None	0	0	15	45	1.0	1	None	0	2.981822	FAM138A	ENST00000417324	0	0	0	None	None	None	85	protein_coding	downstream	LOW	None	None	None	None	None	None	None	17	None	35.61	0	0	30	0.0	0.0	35.38	30	None	None	None	None	0	None	None	None	0	1	0.8	0.89	0.48	0.73	0.73	None	None	None	None	0	None	None	None	R	R	R	R	R	unknown	None	./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,T/T,./.,T/T,./.,./.,./.,./.,T/T,T/T,T/T,T/T,./.,T/T,./.,T/T,./.,./.,./.,./.,T/T,T/T,./.,./.,./.,./.,./.,T/T,./.,T/T,T/T,./.,./.,./.,./.,T/T,T/T,./.,./.,./.,./.,./.,./." > exp
+echo "chr1	30547	30548	T	G	./.,./.,./.,./.,./.,./.,T/T,./.,./.,./.,./.,./.,./.,T/T,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,G/G,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,T/T,./.,G/G,./.,G/G,./.,./.,./.,./.,./.,T/T,./.,./.,./.,./.,./.,./.,./.
+chr1	30859	30860	G	C	G/G,G/G,G/G,G/G,./.,./.,G/G,./.,G/G,G/G,G/G,./.,./.,G/G,G/G,./.,./.,./.,./.,./.,G/G,./.,./.,G/G,./.,G/G,G/G,G/G,G/G,C/C,G/G,./.,G/G,./.,./.,./.,./.,./.,./.,./.,./.,./.,G/C,./.,G/G,./.,G/G,./.,./.,G/G,G/G,G/G,G/G,./.,./.,./.,./.,./.,./.,./.
+chr1	30866	30869	CCT	C	CCT/CCT,CCT/CCT,CCT/C,CCT/CCT,./.,./.,CCT/CCT,./.,CCT/CCT,CCT/C,CCT/CCT,./.,./.,CCT/CCT,CCT/CCT,./.,./.,./.,./.,./.,CCT/CCT,./.,./.,CCT/C,./.,CCT/CCT,C/C,CCT/CCT,CCT/CCT,CCT/CCT,CCT/CCT,./.,CCT/CCT,./.,./.,./.,./.,CCT/CCT,./.,./.,./.,./.,CCT/C,./.,CCT/CCT,./.,CCT/CCT,CCT/CCT,./.,CCT/CCT,CCT/CCT,CCT/CCT,CCT/CCT,./.,./.,./.,./.,./.,./.,./.
+chr1	30894	30895	T	C	T/C,T/C,T/T,T/T,./.,./.,T/T,./.,T/T,T/T,T/T,./.,T/T,T/T,T/T,./.,./.,./.,T/T,./.,T/T,./.,./.,T/T,./.,./.,T/T,T/T,T/T,C/C,T/T,./.,T/T,./.,./.,./.,./.,T/T,./.,./.,./.,./.,T/T,./.,T/T,./.,T/T,T/T,./.,./.,T/T,T/T,T/T,T/T,./.,./.,./.,./.,./.,./.
+chr1	30922	30923	G	T	./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,./.,T/T,./.,T/T,./.,./.,./.,./.,T/T,T/T,T/T,T/T,./.,T/T,./.,T/T,./.,./.,./.,./.,T/T,T/T,./.,./.,./.,./.,./.,T/T,./.,T/T,T/T,./.,./.,./.,./.,T/T,T/T,./.,./.,./.,./.,./.,./." > exp
 gemini query -q "select *, gts \
                   from variants \
-                  limit 5" test.query.db > obs
+                  limit 5" test.query.db | awk '{OFS="\t"}{print $1,$2,$3,$7,$8,$NF}' > obs
 check obs exp
 rm obs exp
 
@@ -425,11 +414,11 @@ echo "10 10:1142207-1142208:C 0 1142207 C C C C C C C C
 10 10:48003991-48003992:C|T 0 48003991 T T C T C T C C
 10 10:52004314-52004315:C 0 52004314 0 0 0 0 C C C C
 10 10:52497528-52497529:C 0 52497528 0 0 C C C C 0 0
-16 16:72057434-72057435:C|T 0 72057434 C T C C C C C C
 10 10:126678091-126678092:A|G 0 126678091 G G G G G G G A
 10 10:135210790-135210791:C|T 0 135210790 T T C C C C T T
 10 10:135336655-135336656:A 0 135336655 0 0 A A 0 0 A A
-10 10:135369531-135369532:C|T 0 135369531 T T T C T C T T" > exp
+10 10:135369531-135369532:C|T 0 135369531 T T T C T C T T
+16 16:72057434-72057435:C|T 0 72057434 C T C C C C C C" > exp
 gemini query --format tped -q "select * from variants" test4.snpeff.ped.db > obs
 check obs exp
 rm obs exp
@@ -438,8 +427,8 @@ rm obs exp
 # 23. Test exclude-phenotype query
 ########################################################################
 echo "    query.t23...\c"
-echo "C/T,C/C,C/C,C/C	1,0,0,0
-G/G,G/G,G/G,G/A	0,0,0,1" > exp
+echo "G/G,G/G,G/G,G/A	0,0,0,1
+C/T,C/C,C/C,C/C	1,0,0,0" > exp
 gemini query --sample-filter "phenotype!=2" --in only -q "select gts, gt_types from variants" test4.snpeff.ped.db > obs
 #gemini query --exclude-phenotype affected -q "select gts, gt_types from variants" test4.snpeff.ped.db > obs
 check obs exp
@@ -507,11 +496,11 @@ chr10	1142207	T	C	3,3,3,3	M10475,M10478,M10500,M128215		M10475,M10478,M10500,M12
 chr10	48003991	C	T	3,1,1,0	M10475,M10478,M10500	M10478,M10500	M10475	1	2	1	0	0
 chr10	52004314	T	C	2,2,3,3	M10500,M128215		M10500,M128215	1	1	0	0	2
 chr10	52497528	G	C	2,3,3,2	M10478,M10500		M10478,M10500	0	2	0	0	2
-chr16	72057434	C	T	1,0,0,0	M10475	M10475		1	0	1	2	0
 chr10	126678091	G	A	0,0,0,1	M128215	M128215		1	0	1	2	0
 chr10	135210790	T	C	0,3,3,0	M10478,M10500		M10478,M10500	0	2	2	0	0
 chr10	135336655	G	A	2,3,2,3	M10478,M128215		M10478,M128215	1	1	0	0	2
-chr10	135369531	T	C	0,1,1,0	M10478,M10500	M10478,M10500		0	2	2	0	0" > exp
+chr10	135369531	T	C	0,1,1,0	M10478,M10500	M10478,M10500		0	2	2	0	0
+chr16	72057434	C	T	1,0,0,0	M10475	M10475		1	0	1	2	0" > exp
 gemini query --show-samples --carrier-summary-by-phenotype affected --header -q "select chrom, start, ref, alt, gt_types from variants" extended_ped.db > obs
 check obs exp
 rm obs exp
@@ -525,7 +514,7 @@ chr10	1142207	1142208	T	C	1
 chr10	48003991	48003992	C	T	1
 chr10	52004314	52004315	T	C	1
 chr10	52497528	52497529	G	C	1
-chr16	72057434	72057435	C	T	1" > exp
+chr10	126678091	126678092	G	A	1" > exp
 gemini query --header --show-families -q "select chrom, start, end, ref, alt from variants limit 5" extended_ped.db > obs
 check obs exp
 rm obs exp
@@ -590,7 +579,136 @@ chr1	69427	69428	T	G	305	OR4F5
 chr1	69510	69511	A	G	305	OR4F5
 chr1	69760	69761	A	T	305	OR4F5" > exp
 gemini query --header -q "select chrom, start, end, ref, alt, aa_length, gene \
-                 from variants" test.query.db | head \
+                 from variants limit 9" test.query.db \
        > obs
 check obs exp
-rm obs exp
\ No newline at end of file
+rm obs exp
+
+#########################################################################
+# 34. Test the gene_detailed table and the join on variants table
+#########################################################################
+echo "    query.t34...\c"
+echo "variant_id	chrom	gene	transcript_status	transcript	transcript_start	transcript_end	synonym	rvis_pct	protein_length	impact
+46	chr1	SAMD11	KNOWN	ENST00000342066	861118	879955	MGC45873	None	681	frame_shift
+578	chr1	TNFRSF18	PUTATIVE	ENST00000486728	1139224	1141060	AITR,CD357,GITR	None	169	frame_shift
+733	chr1	SCNN1D	NOVEL	ENST00000470022	1217305	1221548	ENaCdelta,dNaCh	96.77990092	138	stop_gain" > exp
+
+gemini query --header -q "select v.variant_id, v.chrom, v.gene, \
+	           g.transcript_status, g.transcript, g.transcript_start, \
+			    g.transcript_end, g.synonym, g.rvis_pct, g.protein_length, \
+				v.impact from variants v, gene_detailed g \
+					
+					WHERE v.chrom = g.chrom AND \
+						  v.gene = g.gene AND v.impact_severity='HIGH' AND \
+						  v.biotype='protein_coding' AND \
+						  v.transcript = g.transcript" test.query.db > obs
+check obs exp
+rm obs exp
+
+#########################################################################
+# 35. Test the gene_detailed table and the join on variant_impacts table
+#########################################################################
+echo "    query.t35...\c"
+echo "gene	transcript_status	transcript	transcript_start	transcript_end	synonym	rvis_pct	protein_length	impact
+SAMD11	KNOWN	ENST00000342066	861118	879955	MGC45873	None	681	frame_shift
+TNFRSF18	PUTATIVE	ENST00000486728	1139224	1141060	AITR,CD357,GITR	None	169	frame_shift
+TNFRSF18	KNOWN	ENST00000379265	1139224	1141951	AITR,CD357,GITR	None	234	frame_shift
+TNFRSF18	KNOWN	ENST00000379268	1138891	1142071	AITR,CD357,GITR	None	241	frame_shift
+TNFRSF18	KNOWN	ENST00000328596	1138888	1141951	AITR,CD357,GITR	None	255	frame_shift
+SCNN1D	NOVEL	ENST00000470022	1217305	1221548	ENaCdelta,dNaCh	96.77990092	138	stop_gain
+SCNN1D	NOVEL	ENST00000470022	1217305	1221548	ENaCdelta,dNaCh	96.77990092	138	frame_shift
+SCNN1D	KNOWN	ENST00000325425	1217489	1227404	ENaCdelta,dNaCh	96.77990092	704	frame_shift
+SCNN1D	KNOWN	ENST00000379116	1215816	1227399	ENaCdelta,dNaCh	96.77990092	802	frame_shift
+SCNN1D	KNOWN	ENST00000338555	1215968	1227404	ENaCdelta,dNaCh	96.77990092	638	frame_shift
+SCNN1D	KNOWN	ENST00000400928	1217576	1227409	ENaCdelta,dNaCh	96.77990092	638	frame_shift" > exp
+
+gemini query --header -q "select v.gene, g.transcript_status,g.transcript, g.transcript_start, \
+	g.transcript_end, g.synonym, g.rvis_pct, g.protein_length, \
+    v.impact from variant_impacts v, gene_detailed g \
+		WHERE v.transcript = g.transcript AND \
+              v.gene = g.gene AND \
+	          v.impact_severity='HIGH' AND \
+              v.biotype='protein_coding'" test.query.db > obs
+
+check obs exp
+rm obs exp
+
+###########################################################################
+# 36. Test the gene_summary table and the join on variants table
+###########################################################################
+echo "    query.t36...\c"
+echo "chrom	gene	strand	transcript_min_start	transcript_max_end	synonym	rvis_pct	impact
+chr1	SAMD11	1	860260	879955	MGC45873	None	frame_shift
+chr1	TNFRSF18	-1	1138888	1142071	AITR,CD357,GITR	None	frame_shift
+chr1	SCNN1D	1	1215816	1227409	ENaCdelta,dNaCh	96.77990092	stop_gain
+chr1	SCNN1D	1	1215816	1227409	ENaCdelta,dNaCh	96.77990092	frame_shift" > exp
+
+gemini query --header -q "select v.chrom, v.gene, g.strand, g.transcript_min_start, g.transcript_max_end, \
+g.synonym, g.rvis_pct, v.impact from variants v, gene_summary g \
+WHERE v.chrom = g.chrom AND \
+v.gene = g.gene AND \
+v.impact_severity='HIGH'" test.query.db > obs
+
+check obs exp
+rm obs exp 
+
+############################################################################
+# 37. Test the gene_summary table and the join on variant_impacts table
+############################################################################
+echo "    query.t37...\c"
+echo "gene	impact	transcript	transcript_min_start	transcript_max_end	rvis_pct	synonym
+SCNN1D	stop_gain	ENST00000470022	1215816	1227409	96.77990092	ENaCdelta,dNaCh" > exp
+
+gemini query --header -q "select g.gene, v.impact, v.transcript, \
+	   g.transcript_min_start, g.transcript_max_end, g.rvis_pct, g.synonym \
+		  from gene_summary g, variant_impacts v \
+			  where g.gene=v.gene AND \
+				g.gene ='SCNN1D' AND \
+				v.impact ='stop_gain'" test.query.db > obs
+check obs exp
+rm obs exp
+
+
+############################################################################
+# 38. Test the loading of gene_summary table with multiple cores
+############################################################################
+echo "    query.t38...\c"
+echo "chrom	gene	strand	transcript_min_start	transcript_max_end	synonym	rvis_pct	impact
+chr1	SAMD11	1	860260	879955	MGC45873	None	frame_shift
+chr1	TNFRSF18	-1	1138888	1142071	AITR,CD357,GITR	None	frame_shift
+chr1	SCNN1D	1	1215816	1227409	ENaCdelta,dNaCh	96.77990092	stop_gain
+chr1	SCNN1D	1	1215816	1227409	ENaCdelta,dNaCh	96.77990092	frame_shift" > exp
+
+gemini query --header -q "select v.chrom, v.gene, g.strand, g.transcript_min_start, g.transcript_max_end, \
+g.synonym, g.rvis_pct, v.impact from variants v, gene_summary g \
+WHERE v.chrom = g.chrom AND \
+v.gene = g.gene AND \
+v.impact_severity='HIGH'" test.query.core.db > obs
+
+check obs exp
+rm obs exp 
+
+###########################################################################
+# 39. Test the loading of gene_detailed table with multiple cores
+###########################################################################
+echo "    query.t34...\c"
+echo "variant_id	chrom	gene	transcript_status	transcript	transcript_start	transcript_end	synonym	rvis_pct	protein_length	impact
+46	chr1	SAMD11	KNOWN	ENST00000342066	861118	879955	MGC45873	None	681	frame_shift
+578	chr1	TNFRSF18	PUTATIVE	ENST00000486728	1139224	1141060	AITR,CD357,GITR	None	169	frame_shift
+733	chr1	SCNN1D	NOVEL	ENST00000470022	1217305	1221548	ENaCdelta,dNaCh	96.77990092	138	stop_gain" > exp
+
+gemini query --header -q "select v.variant_id, v.chrom, v.gene, \
+	           g.transcript_status, g.transcript, g.transcript_start, \
+			    g.transcript_end, g.synonym, g.rvis_pct, g.protein_length, \
+				v.impact from variants v, gene_detailed g \
+					
+					WHERE v.chrom = g.chrom AND \
+						  v.gene = g.gene AND v.impact_severity='HIGH' AND \
+						  v.biotype='protein_coding' AND \
+						  v.transcript = g.transcript" test.query.core.db > obs
+check obs exp
+rm obs exp
+
+############################################################################
+ 
+ 
\ No newline at end of file
